// ../code-standard/dist/index.mjs
var CDN = "https://testingcf.jsdelivr.net";
var span;
if (typeof document === "object") {
  span = document.createElement("span");
}
var getObject = (key) => JSON.parse(String(localStorage.getItem(key)));
var setObject = (key, value) => {
  localStorage.setItem(key, JSON.stringify(value));
};

// src/static.ts
var getStaticMwConfig = ({
  parserFunction: [p0, p1, ...p2],
  protocol,
  nsid,
  variants,
  redirection,
  ext,
  doubleUnderscore: [d0, d1, d2],
  img
}, modes) => ({
  tags: Object.fromEntries(ext.map((s) => [s, true])),
  tagModes: modes,
  doubleUnderscore: [
    Object.fromEntries((d2 && d0.length === 0 ? Object.keys(d2) : d0).map((s) => [`__${s}__`, true])),
    Object.fromEntries(d1.map((s) => [`__${s}__`, true]))
  ],
  functionSynonyms: [
    {
      ...p0,
      ...Object.fromEntries(p2.flat().map((s) => [s, s]))
    },
    Object.fromEntries(p1.map((s) => [s, true]))
  ],
  urlProtocols: `${protocol}|//`,
  nsid,
  img: Object.fromEntries(Object.entries(img).map(([k, v]) => [k, `img_${v}`])),
  variants,
  redirection
});

// mw/config.ts
var _a;
var ALL_SETTINGS_CACHE = (_a = getObject("InPageEditMwConfig")) != null ? _a : {};
var SITE_ID = typeof mw === "object" ? mw.config.get("wgServerName") + mw.config.get("wgScriptPath") : location.origin;
var SITE_SETTINGS = ALL_SETTINGS_CACHE[SITE_ID];
var VALID = Number(SITE_SETTINGS == null ? void 0 : SITE_SETTINGS.time) > Date.now() - 86400 * 1e3 * 30;
var getConfig = (magicWords, rule, flip) => Object.fromEntries(
  magicWords.filter(rule).filter(({ "case-sensitive": i }) => i !== flip).flatMap(({ aliases, name, "case-sensitive": i }) => aliases.map((alias) => ({
    alias: (i ? alias : alias.toLowerCase()).replace(/:$/u, ""),
    name
  }))).map(({ alias, name }) => [alias, name])
);
var getConfigPair = (magicWords, rule) => [true, false].map((bool) => getConfig(magicWords, rule, bool));
var setConfig = (config) => {
  mw.config.set("extCodeMirrorConfig", config);
};
var getMwConfig = async (modes) => {
  if (mw.loader.getState("ext.CodeMirror") !== null && !VALID) {
    await mw.loader.using(mw.loader.getState("ext.CodeMirror.data") ? "ext.CodeMirror.data" : "ext.CodeMirror");
  }
  let config = mw.config.get("extCodeMirrorConfig");
  if (!config && VALID) {
    ({ config } = SITE_SETTINGS);
    setConfig(config);
  }
  const isIPE = config && Object.values(config.functionSynonyms[0]).includes(true), nsid = mw.config.get("wgNamespaceIds");
  if ((config == null ? void 0 : config.img) && config.redirection && config.variants && !isIPE) {
    config.urlProtocols = config.urlProtocols.replace(/\\:/gu, ":");
    config.tagModes = modes;
    return { ...config, nsid };
  } else if (location.hostname.endsWith(".moegirl.org.cn")) {
    const parserConfig = await (await fetch(
      `${CDN}/npm/wikiparser-node@browser/config/moegirl.json`
    )).json();
    setObject("wikilintConfig", parserConfig);
    config = getStaticMwConfig(parserConfig, modes);
  } else {
    await mw.loader.using("mediawiki.api");
    const { query: { general: { variants }, magicwords, extensiontags, functionhooks, variables } } = await new mw.Api().get({
      meta: "siteinfo",
      siprop: [
        "general",
        "magicwords",
        ...config && !isIPE ? [] : ["extensiontags", "functionhooks", "variables"]
      ],
      formatversion: "2"
    });
    const others = /* @__PURE__ */ new Set(["msg", "raw", "msgnw", "subst", "safesubst"]);
    if (config && !isIPE) {
      const { functionSynonyms: [insensitive] } = config;
      if (!("subst" in insensitive)) {
        Object.assign(insensitive, getConfig(magicwords, ({ name }) => others.has(name)));
      }
    } else {
      const functions = /* @__PURE__ */ new Set([
        ...functionhooks,
        ...variables,
        ...others
      ]);
      config = {
        tags: Object.fromEntries(extensiontags.map((tag) => [tag.slice(1, -1), true])),
        functionSynonyms: getConfigPair(magicwords, ({ name }) => functions.has(name)),
        doubleUnderscore: getConfigPair(
          magicwords,
          ({ aliases }) => aliases.some((alias) => /^__.+__$/u.test(alias))
        )
      };
    }
    config.tagModes = modes;
    config.img = getConfig(magicwords, ({ name }) => name.startsWith("img_"));
    config.variants = variants ? variants.map(({ code }) => code) : [];
    config.redirection = magicwords.find(({ name }) => name === "redirect").aliases;
    config.urlProtocols = mw.config.get("wgUrlProtocols").replace(/\\:/gu, ":");
  }
  setConfig(config);
  ALL_SETTINGS_CACHE[SITE_ID] = { config, time: Date.now() };
  setObject("InPageEditMwConfig", ALL_SETTINGS_CACHE);
  return { ...config, nsid };
};
var getParserConfig = (minConfig, mwConfig) => {
  var _a2;
  let config = getObject("wikilintConfig");
  if (config) {
    return config;
  }
  config = {
    ...minConfig,
    ext: Object.keys(mwConfig.tags),
    namespaces: mw.config.get("wgFormattedNamespaces"),
    nsid: mwConfig.nsid,
    doubleUnderscore: mwConfig.doubleUnderscore.map(
      (obj) => Object.keys(obj).map((s) => s.slice(2, -2))
    ),
    variants: mwConfig.variants,
    protocol: mwConfig.urlProtocols.replace(/\|\\?\/\\?\//u, ""),
    redirection: (_a2 = mwConfig.redirection) != null ? _a2 : minConfig.redirection
  };
  if (location.hostname.endsWith(".moegirl.org.cn")) {
    config.html[2].push("img");
  }
  [config.parserFunction[0]] = mwConfig.functionSynonyms;
  if (mw.loader.getState("ext.CodeMirror") === null) {
    for (const [key, val] of Object.entries(mwConfig.functionSynonyms[0])) {
      if (!key.startsWith("#")) {
        config.parserFunction[0][`#${key}`] = val;
      }
    }
  }
  config.parserFunction[1] = [
    ...Object.keys(mwConfig.functionSynonyms[1]),
    "="
  ];
  for (const [key, val] of Object.entries(mwConfig.img)) {
    config.img[key] = val.slice(4);
  }
  return config;
};
export {
  getMwConfig,
  getParserConfig
};
